==> deepin-scanner_0.1.9.tar.xz: BUILD/translations/deepin-scanner_ml.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/main.cpp" line="34"/>
        <source>Deepin Scanner</source>
        <translation>ഡീപിന്‍ സ്കാനറുകൾ</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="38"/>
        <source>Scanner Manager is a scanner tool that supports a variety of scanning devices</source>
        <translation>സ്കാന്‍ മാനേജര്‍ ഒരു സ്കാനറ്‍ ഉപകരണമാണ് അത് വിവിധ സ്കാനിംഗ് ഉപകരണങ്ങൾക്ക് പിന്തുണയും നല്‍കുന്നു</translation>
    </message>
</context>
<context>
    <name>LoadingDialog</name>
    <message>
        <location filename="../src/ui/loadingdialog.cpp" line="23"/>
        <source>Loading...</source>
        <translation>ലോഡിംഗ്...</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="40"/>
        <source>Scanner Manager</source>
        <translation>സ്കാന്‍ മാനേജര്‍</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="96"/>
        <source>Loading devices...</source>
        <translation>ഉപകരണങ്ങൾ ലോഡിംഗ്...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="124"/>
        <source>Opening device...</source>
        <translation>ഉപകരണം തുറക്കുന്നു...</translation>
    </message>
</context>
<context>
    <name>ScanWidget</name>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="68"/>
        <source>Scan Settings</source>
        <translation>സ്കാന്‍ സെറ്റിംഗ്സ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="94"/>
        <source>Resolution</source>
        <translation>ക്ഷമത</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="105"/>
        <source>Color Mode</source>
        <translation>വർഗ്ഗം മോഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="116"/>
        <source>Image Format</source>
        <translation>ചിത്രം പോര്‍ട്ട്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="134"/>
        <source>Scan</source>
        <translation>സ്കാന്‍</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="141"/>
        <source>View Scanned Image</source>
        <translation>സ്കാന്‍ ചെയ്ത ചിത്രം കാണുക</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="155"/>
        <source>Scan history will be shown here</source>
        <translation>സ്കാന്‍ ചരിത്രം ഈ സ്ഥലത്ത് കാണിക്കും</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="202"/>
        <source>Scan Mode</source>
        <translation>സ്കാന്‍ മോഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="203"/>
        <source>Flatbed</source>
        <translation>ഫ്ലാറ്റ്‌ബെഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="206"/>
        <source>Video Format</source>
        <translation>വീഡിയോ പോര്‍ട്ട്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Color</source>
        <translation>വർഗ്ഗം</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Grayscale</source>
        <translation>ഗ്രേ സ്കേല്‍</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Black White</source>
        <translation>കറുപ്പ് ചുവപ്പ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="251"/>
        <source>Device not initialized</source>
        <translation>ഉപകരണം പ്രാപ്തമായിട്ടില്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="305"/>
        <source>Initializing preview...</source>
        <translation>പ്രീവ്യൂ പ്രാപ്തമാക്കുന്നു...</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="311"/>
        <source>Device preview not available</source>
        <translation>ഉപകരണ പ്രീവ്യൂ ലഭ്യമല്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="336"/>
        <source>No preview image</source>
        <translation>പ്രീവ്യൂ ചിത്രം ഒന്നുമില്ല</translation>
    </message>
</context>
<context>
    <name>ScannerDevice</name>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="227"/>
        <source>No scanner devices found. Possible solutions:
1. Ensure scanner is connected and powered on
2. Run command: sudo gpasswd -a $USER scanner
3. Restart SANE: sudo service saned restart
4. Install required driver package: sudo apt-get install libsane-extras
5. For network scanners, check network configuration
6. Reconnect USB cable or restart computer</source>
        <translation>സ്കാനറ്‍ ഉപകരണങ്ങൾ കണ്ടെത്താനായില്ല. സാധ്യമായ പരിഹാരങ്ങൾ:
1. സ്കാനറ്‍ കണക്ട് ചെയ്യുക അത് പവർ ഓൺ ചെയ്യുക
2. കമാൻഡ് ഓപ്പറേറ്റ്: sudo gpasswd -a $USER scanner
3. SANE റീസ്റ്റാർട്ട് ചെയ്യുക: sudo service saned restart
4. ആവശ്യമായ ഡ്രൈവറ്‍ പേക്കേജ് ഇൻസ്റ്റാൾ ചെയ്യുക: sudo apt-get install libsane-extras
5. നെറ്റ്വർക്ക് സ്കാനറുകൾക്ക്, നെറ്റ്വർക്ക് കോൺഫിഗർ ചെയ്യുക
6. USB കേബിള്‍ പുനഃസ്ഥാപിക്കുക അല്ലെങ്കിൽ കമ്പ്യൂട്ടര്‍ റീസ്റ്റാർട്ട് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="364"/>
        <source>Scanner not opened</source>
        <translation>സ്കാനറ്‍ തുറന്നിട്ടില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="374"/>
        <source>Failed to get scanner parameters: %1</source>
        <translation>സ്കാനറ്‍ പാരാമീറ്ററുകൾ നേടാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="389"/>
        <source>Failed to start scan: %1</source>
        <translation>സ്കാന്‍ ആരംഭിക്കാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="901"/>
        <source>Failed to save test image</source>
        <translation>ടെസ്റ്റ് ചിത്രം സംരക്ഷിക്കാനായില്ല</translation>
    </message>
</context>
<context>
    <name>ScannersWidget</name>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="29"/>
        <source>Scanner Devices</source>
        <translation>സ്കാനറ്‍ ഉപകരണങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="72"/>
        <source>Scanner</source>
        <translation>സ്കാനറുകൾ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="144"/>
        <source>Idle</source>
        <translation>ഇടം</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="78"/>
        <source>Webcam</source>
        <translation>വെബ്ക്യാമ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="83"/>
        <source>No devices found</source>
        <translation>ഉപകരണങ്ങൾ കണ്ടെത്താനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="152"/>
        <source>Model: %1</source>
        <translation>മോഡൽ: %1</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="153"/>
        <source>Status: %1</source>
        <translation>സ്റ്റേറ്റസ്: %1</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="128"/>
        <source>Scan</source>
        <translation>സ്കാൻ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="148"/>
        <source>Offline</source>
        <translation>ഓഫ്‌ലൈൻ</translation>
    </message>
</context>
<context>
    <name>WebcamDevice</name>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="264"/>
        <source>Cannot get device path, cannot set resolution</source>
        <translation>ഉപകരണ വിലാസം നേടാനായില്ല, പരിഹാരം നിർണയിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="273"/>
        <source>Failed to reopen device</source>
        <translation>ഉപകരണം പുനഃപ്രാപിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="307"/>
        <source>Failed to set requested resolution</source>
        <translation>ആവശ്യപ്പെട്ട പരിഹാരം നിർണയിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="320"/>
        <source>Memory mapping failed</source>
        <translation>മെമറി മാപ്പിംഗ് പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="360"/>
        <source>Device not properly initialized</source>
        <translation>ഉപകരണം ശരിയായി പ്രാപിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="390"/>
        <source>Buffer initialization failed</source>
        <translation>ബഫർ് പ്രാപിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="406"/>
        <source>Buffer reinitialization failed</source>
        <translation>ബഫർ് പുനഃപ്രാപിക്കാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="437"/>
        <source>Failed to enqueue buffer: %1</source>
        <translation>ബഫർ് ക്വിച്ച് ചെയ്യാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="448"/>
        <source>Failed to start video stream: %1</source>
        <translation>വീഡിയോ സ്ട്രീമിംഗ് ആരംഭിക്കാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="539"/>
        <source>Device not initialized or invalid file descriptor</source>
        <translation>ഉപകരണം പ്രാപിക്കാനായില്ല അല്ലെങ്കിൽ തെറാജ് ഫയൽ ഡസ്ക്രിപ്റ്റർ</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="559"/>
        <source>Failed to start video stream, capture failed</source>
        <translation>വീഡിയോ സ്ട്രീമിംഗ് ആരംഭിക്കാനായില്ല, പകർപ്പ് പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="600"/>
        <source>Failed to get image frame</source>
        <translation>ചിത്ര റാം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="654"/>
        <source>Failed to capture valid image, please check camera connection</source>
        <translation>പരിഹാരം ചെയ്യാനായില്ല, ക്യാമറ കണക്ഷൻ പരിശോധിക്കുക</translation>
    </message>
</context>
</TS>

==> deepin-scanner_0.1.17.tar.xz: BUILD/translations/deepin-scanner_ml.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/main.cpp" line="34"/>
        <source>Deepin Scanner</source>
        <translation>ഡീപിന്‍ സ്കാനർ</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="38"/>
        <source>Scanner Manager is a scanner tool that supports a variety of scanning devices</source>
        <translation>സ്കാനർ മാനേജർ ഒരു സ്കാനർ ഉപകരണമാണ് അത് പല തരത്തിലുള്ള സ്കാനിംഗ് ഉപകരണങ്ങളും പിന്തുണയ്ക്കുന്നു</translation>
    </message>
</context>
<context>
    <name>LoadingDialog</name>
    <message>
        <location filename="../src/ui/loadingdialog.cpp" line="23"/>
        <source>Loading...</source>
        <translation>ലോഡിംഗ്...</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="40"/>
        <source>Scanner Manager</source>
        <translation>സ്കാനർ മാനേജർ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="96"/>
        <source>Loading devices...</source>
        <translation>ലോറ്റിംഗ് ഉപകരണങ്ങൾ...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="124"/>
        <source>Opening device...</source>
        <translation>ഉപകരണം തുറക്കുന്നു...</translation>
    </message>
</context>
<context>
    <name>ScanWidget</name>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="68"/>
        <source>Scan Settings</source>
        <translation>സ്കാന്‍ സെറ്റിംഗ്സ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="94"/>
        <source>Resolution</source>
        <translation>രേഖാംശം</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="105"/>
        <source>Color Mode</source>
        <translation>കളർ മോഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="116"/>
        <source>Image Format</source>
        <translation>ചിത്രം ഫോർമാറ്റ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="134"/>
        <source>Scan</source>
        <translation>സ്കാന്‍ ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="141"/>
        <source>View Scanned Image</source>
        <translation>സ്കാന്‍ ചെയ്ത ചിത്രം കാണുക</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="155"/>
        <source>Scan history will be shown here</source>
        <translation>സ്കാന്‍ ചെയ്ത ചിത്രങ്ങളുടെ ചരിത്രം ഇവിടെ കാണാം</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="202"/>
        <source>Scan Mode</source>
        <translation>സ്കാന്‍ മോഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="203"/>
        <source>Flatbed</source>
        <translation>ഫ്ലാറ്റ്‌ബെഡ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="206"/>
        <source>Video Format</source>
        <translation>വിഡിയോ ഫോർമാറ്റ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Color</source>
        <translation>കളർ</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Grayscale</source>
        <translation>ഗ്രേസ്കേൽ</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="210"/>
        <source>Black White</source>
        <translation>ബ്ലാക്ക് വൈറ്റ്</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="251"/>
        <source>Device not initialized</source>
        <translation>ഉപകരണം പ്രാപ്തമായിട്ടില്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="305"/>
        <source>Initializing preview...</source>
        <translation>പ്രീവ്യൂ പ്രാപ്തമാക്കുന്നു...</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="311"/>
        <source>Device preview not available</source>
        <translation>ഉപകരണം പ്രീവ്യൂ ലഭ്യമായിട്ടില്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scanwidget.cpp" line="336"/>
        <source>No preview image</source>
        <translation>പ്രീവ്യൂ ചിത്രം ലഭ്യമല്ല</translation>
    </message>
</context>
<context>
    <name>ScannerDevice</name>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="227"/>
        <source>No scanner devices found. Possible solutions:
1. Ensure scanner is connected and powered on
2. Run command: sudo gpasswd -a $USER scanner
3. Restart SANE: sudo service saned restart
4. Install required driver package: sudo apt-get install libsane-extras
5. For network scanners, check network configuration
6. Reconnect USB cable or restart computer</source>
        <translation>സ്കാനർ ഉപകരണങ്ങൾ കണ്ടെത്താൻ കഴിയാത്തു. സാധ്യമായ പരിഹാരങ്ങൾ:
1. സ്കാനർ ഇനിഷ്യലൈസ് ചെയ്യുക
2. കമാൻഡ് ഓപ്പറേറ്റ് ചെയ്യുക: sudo gpasswd -a $USER scanner
3. SANE പുനർജ്ജീവനം നല്കുക: sudo service saned restart
4. ആവശ്യമായ ഡ്രൈവർ പാക്കേജ് ഇൻസ്റ്റാൾ ചെയ്യുക: sudo apt-get install libsane-extras
5. നെറ്റ്വർക്ക് സ്കാനർകൾക്ക്, നെറ്റ്വർക്ക് കൺഫിഗർ ചെയ്യുക
6. USB കേബിൾ പുനർജ്ജീവനം നല്കുക അല്ലെങ്കിൽ കമ്പ്യൂട്ടർ പുനർജ്ജീവനം നല്കുക</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="364"/>
        <source>Scanner not opened</source>
        <translation>സ്കാനർ തുറന്നിട്ടില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="374"/>
        <source>Failed to get scanner parameters: %1</source>
        <translation>സ്കാനർ പാരമേറ്ററുകൾ നേടാൻ പരാജയപ്പെട്ടു: %1</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="389"/>
        <source>Failed to start scan: %1</source>
        <translation>സ്കാന്‍ ആരംഭിക്കാൻ പരാജയപ്പെട്ടു: %1</translation>
    </message>
    <message>
        <location filename="../src/device/scannerdevice.cpp" line="901"/>
        <source>Failed to save test image</source>
        <translation>ടെസ്റ്റ് ചിത്രം സേവ് ചെയ്യാൻ പരാജയപ്പെട്ടു</translation>
    </message>
</context>
<context>
    <name>ScannersWidget</name>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="29"/>
        <source>Scanner Devices</source>
        <translation>സ്കാനർ ഉപകരണങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="72"/>
        <source>Scanner</source>
        <translation>സ്കാനർ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="144"/>
        <source>Idle</source>
        <translation>ഇരുത്തിയിരിക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="78"/>
        <source>Webcam</source>
        <translation>വെബ്ക്യാമുകൾ</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="83"/>
        <source>No devices found</source>
        <translation>ഉപകരണങ്ങൾ കണ്ടെത്താനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="152"/>
        <source>Model: %1</source>
        <translation>സാങ്കേതിക വിശദീകരണം: %1</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="153"/>
        <source>Status: %1</source>
        <translation>നില: %1</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="128"/>
        <source>Scan</source>
        <translation>സ്കാൻ ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../src/ui/scannerswidget.cpp" line="148"/>
        <source>Offline</source>
        <translation>ഓഫ്‌ലൈൻ</translation>
    </message>
</context>
<context>
    <name>WebcamDevice</name>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="264"/>
        <source>Cannot get device path, cannot set resolution</source>
        <translation>ഉപകരണ വിലാസം നേടാനായില്ല, പരിഹാരം നിലനിർത്താനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="273"/>
        <source>Failed to reopen device</source>
        <translation>ഉപകരണം പുനഃപ്രാപ്തി നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="307"/>
        <source>Failed to set requested resolution</source>
        <translation>ആവശ്യപ്പെട്ട പരിഹാരം നിലനിർത്താനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="320"/>
        <source>Memory mapping failed</source>
        <translation>സ്മൃതി മാപ്പിംഗ് വിശദീകരണം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="360"/>
        <source>Device not properly initialized</source>
        <translation>ഉപകരണം ശരിയായി പ്രാപ്തി നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="390"/>
        <source>Buffer initialization failed</source>
        <translation>ബഫർ് പ്രാപ്തി വിശദീകരണം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="406"/>
        <source>Buffer reinitialization failed</source>
        <translation>ബഫർ് പുനഃപ്രാപ്തി വിശദീകരണം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="437"/>
        <source>Failed to enqueue buffer: %1</source>
        <translation>ബഫർ് പുനഃപ്രാപ്തി ചെയ്യാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="448"/>
        <source>Failed to start video stream: %1</source>
        <translation>വീഡിയോ സ്ട്രീം ആരംഭിക്കാനായില്ല: %1</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="539"/>
        <source>Device not initialized or invalid file descriptor</source>
        <translation>ഉപകരണം പ്രാപ്തി നേടാനായില്ല അല്ലെങ്കിൽ തെറാജി ഫയൽ ഡസ്പർക്ടർ</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="559"/>
        <source>Failed to start video stream, capture failed</source>
        <translation>വീഡിಯോ സ്ട്രീം ആരംഭിക്കാനായില്ല, പകർപ്പ് വിശദീകരണം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="600"/>
        <source>Failed to get image frame</source>
        <translation>ചിത്രം ഫ്രെയം നേടാനായില്ല</translation>
    </message>
    <message>
        <location filename="../src/device/webcamdevice.cpp" line="654"/>
        <source>Failed to capture valid image, please check camera connection</source>
        <translation>പരിപാലന ചിത്രം നേടാനായില്ല, ക്യാമറ കണക്ഷൻ പരിശോധിക്കുക</translation>
    </message>
</context>
</TS>
